==> FlightGear-0.19.tar.gz: FlightGear/Src/Flight/LaRCsim/navion_engine.c <==
/***************************************************************************

	TITLE:		engine.c
	
----------------------------------------------------------------------------

	FUNCTION:	dummy engine routine

----------------------------------------------------------------------------

	MODULE STATUS:	incomplete

----------------------------------------------------------------------------

	GENEALOGY:	Created 15 OCT 92 as dummy routine for checkout. EBJ

----------------------------------------------------------------------------

	DESIGNED BY:	designer
	
	CODED BY:	programmer
	
	MAINTAINED BY:	maintainer

----------------------------------------------------------------------------

	MODIFICATION HISTORY:
	
	DATE	PURPOSE						BY

	CURRENT RCS HEADER INFO:

$Header: /home/home3/curt/CVS/FlightGear/LaRCsim/navion_engine.c,v 1.4 1997/07/10 04:26:36 curt Exp $

 * Revision 1.1  92/12/30  13:21:46  bjax
 * Initial revision
 * 

----------------------------------------------------------------------------

	REFERENCES:

----------------------------------------------------------------------------

	CALLED BY:	ls_model();

----------------------------------------------------------------------------

	CALLS TO:	none

----------------------------------------------------------------------------

	INPUTS:

----------------------------------------------------------------------------

	OUTPUTS:

--------------------------------------------------------------------------*/
#include <math.h>
#include "ls_types.h"
#include "ls_constants.h"
#include "ls_generic.h"
#include "ls_cockpit.h"
#include "ls_sim_control.h"


void engine( SCALAR dt, int init )

{
    if (init || sim_control_.sim_type != cockpit) 
	Throttle[3] = Throttle_pct;

    /* F_X_engine = Throttle[3]*813.4/0.2; */  /* original code */
    /* F_Z_engine = Throttle[3]*11.36/0.2; */  /* original code */
    F_X_engine = Throttle[3]*813.4/0.85;
    F_Z_engine = Throttle[3]*11.36/0.85;

    Throttle_pct = Throttle[3];
}

==> FlightGear-0.29.tar.gz: FlightGear/Src/Flight/LaRCsim/navion_engine.c <==
/***************************************************************************

	TITLE:		engine.c
	
----------------------------------------------------------------------------

	FUNCTION:	dummy engine routine

----------------------------------------------------------------------------

	MODULE STATUS:	incomplete

----------------------------------------------------------------------------

	GENEALOGY:	Created 15 OCT 92 as dummy routine for checkout. EBJ

----------------------------------------------------------------------------

	DESIGNED BY:	designer
	
	CODED BY:	programmer
	
	MAINTAINED BY:	maintainer

----------------------------------------------------------------------------

	MODIFICATION HISTORY:
	
	DATE	PURPOSE						BY

	CURRENT RCS HEADER INFO:

$Header: /home/home17/curt/CVS/FlightGear/LaRCsim/navion_engine.c,v 1.5 1998/01/19 18:40:29 curt Exp $

 * Revision 1.1  92/12/30  13:21:46  bjax
 * Initial revision
 * 

----------------------------------------------------------------------------

	REFERENCES:

----------------------------------------------------------------------------

	CALLED BY:	ls_model();

----------------------------------------------------------------------------

	CALLS TO:	none

----------------------------------------------------------------------------

	INPUTS:

----------------------------------------------------------------------------

	OUTPUTS:

--------------------------------------------------------------------------*/
#include <math.h>
#include "ls_types.h"
#include "ls_constants.h"
#include "ls_generic.h"
#include "ls_sim_control.h"
#include "ls_cockpit.h"

extern SIM_CONTROL	sim_control_;

void engine( SCALAR dt, int init ) {
    /* if (init) { */
    Throttle[3] = Throttle_pct;
    /* } */

    /* F_X_engine = Throttle[3]*813.4/0.2; */  /* original code */
    /* F_Z_engine = Throttle[3]*11.36/0.2; */  /* original code */
    F_X_engine = Throttle[3]*813.4/0.85;
    F_Z_engine = Throttle[3]*11.36/0.85;

    Throttle_pct = Throttle[3];
}
